@@ -90,10 +90,10 @@ Blockly.Python.SoundThread_get=function(a){
 }
 
 Blockly.Python.classifier_win_init=function(a){
-    Blockly.Python.definitions_['yolo_fast_init'] = 'from Mx import classifier_win as classwin';
+    Blockly.Python.definitions_['yolo_fast_init'] = 'from Mx.classifier_win import classifier as classwin';
     var model = Blockly.Python.valueToCode(this,'MODEL',Blockly.Python.ORDER_ASSIGNMENT);
     var label = Blockly.Python.valueToCode(this,'CLASS',Blockly.Python.ORDER_ASSIGNMENT);
-    var code= 'classwin.init(r'+model+','+label+')';
+    var code= 'classwin(r'+model+','+label+')';
     return [code,Blockly.Python.ORDER_ATOMIC];
 }
 
