@@ -88,6 +88,9 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'pro_category': {
         'colour': "#6D318E",
       },
+      'robot_category': {
+        'colour': "#346fef",
+      },
     },
     'blockStyles': {
      'list_blocks': {
@@ -174,6 +177,11 @@ Blockly.Themes.Halloween = Blockly.Theme.defineTheme('halloween', {
       'colourPrimary': "#00a8a8",
       'colourSecondary':"#fff",
       'colourTertiary':"#00a8a8"
+    }, 
+    'robot_blocks': {
+      'colourPrimary': "#346fef",
+      'colourSecondary':"#fff",
+      'colourTertiary':"#346fef"
     }, 
      'text_blocks': {
        'colourPrimary': "#f0932b",
@@ -516,10 +524,23 @@ window.onload = function () {      /*chushihua*/
       console.log(data)
       openfile(data['data'])
     }
-    else if(data['msg']=='remote_desktop'){
+    else if(data['msg']=='windows_remote_desktop'){
       var path='data:image/png;base64,'+data['data']
       $("#dk").attr('src',path);
     }
+    else if(data['msg']=='Liunx_remote_desktop'){
+      var path='data:image/png;base64,'+data['data']
+      $.ajax({
+        url:"./getip",
+        type:"GET",
+        data:{},
+        success:function(data1){
+          ip=data1
+          html='<iframe src="http://'+ip+':6080/vnc.html" style="width:100%;height:100%"></iframe>'
+          document.getElementById('DK_s').innerHTML=html
+          }
+        })
+    }
   }
  var oBox = document.getElementById("blockly_box"); 
  var oTop = document.getElementById("blocklyDiv"); 
@@ -767,9 +788,9 @@ function QuickDemo(){
     autoOpen    : false,
     buttons         : {
       close           : true,          // Boolean
-      maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      maximize        : true,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -780,7 +801,7 @@ function QuickDemo(){
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
 
@@ -791,9 +812,9 @@ function QuickDemo(){
       autoOpen    : false,
       buttons         : {
         close           : true,          // Boolean
-        maximize        : false,          // Boolean
-        collapse        : false,          // Boolean
-        minimize        : false,          // Boolean
+        maximize        : true,          // Boolean
+        collapse        : true,          // Boolean
+        minimize        : true,          // Boolean
     },
     buttonsTexts        : {
       close               : "退出",
@@ -804,7 +825,7 @@ function QuickDemo(){
     draggable           : true,
     nativeDrag          : true,
     dragOpacity         : 1,
-    resizable:false,
+    resizable:true,
     resizeOpacity: 1,
   });
   $("#file_content").PopupWindow({
@@ -814,9 +835,9 @@ function QuickDemo(){
     autoOpen    : false,
     buttons         : {
       close           : true,          // Boolean
-      maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      maximize        : true,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -827,7 +848,7 @@ function QuickDemo(){
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
 });
 $("#HSV_content").PopupWindow({
@@ -837,9 +858,9 @@ $("#HSV_content").PopupWindow({
   autoOpen    : false,
   buttons         : {
     close           : true,          // Boolean
-    maximize        : false,          // Boolean
-    collapse        : false,          // Boolean
-    minimize        : false,          // Boolean
+    maximize        : true,          // Boolean
+    collapse        : true,          // Boolean
+    minimize        : true,          // Boolean
 },
 buttonsTexts        : {
   close               : "退出",
@@ -850,19 +871,19 @@ buttonsTexts        : {
 draggable           : true,
 nativeDrag          : true,
 dragOpacity         : 1,
-resizable:false,
+resizable:true,
 resizeOpacity: 1,
 });
 $("#DK_content").PopupWindow({
-  height      : 700,
+  height      : 740,
   width       : 1200,
-  title       : "桌面图像",
+  title       : "远程桌面",
   autoOpen    : false,
   buttons         : {
     close           : true,          // Boolean
-    maximize        : false,          // Boolean
-    collapse        : false,          // Boolean
-    minimize        : false,          // Boolean
+    maximize        : true,          // Boolean
+    collapse        : true,          // Boolean
+    minimize        : true,          // Boolean
 },
 buttonsTexts        : {
   close               : "退出",
@@ -873,7 +894,7 @@ buttonsTexts        : {
 draggable           : true,
 nativeDrag          : true,
 dragOpacity         : 1,
-resizable:false,
+resizable:true,
 resizeOpacity: 1,
 });
 $("#hear_content").PopupWindow({
@@ -884,8 +905,8 @@ $("#hear_content").PopupWindow({
   buttons         : {
     close           : true,          // Boolean
     maximize        : false,          // Boolean
-    collapse        : false,          // Boolean
-    minimize        : false,          // Boolean
+    collapse        : true,          // Boolean
+    minimize        : true,          // Boolean
 },
 buttonsTexts        : {
   close               : "退出",
@@ -896,7 +917,7 @@ buttonsTexts        : {
 draggable           : true,
 nativeDrag          : true,
 dragOpacity         : 1,
-resizable:false,
+resizable:true,
 resizeOpacity: 1,
 });
   $("#Rexample_content").PopupWindow({
@@ -907,8 +928,8 @@ resizeOpacity: 1,
     buttons         : {
       close           : true,          // Boolean
       maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -919,7 +940,7 @@ resizeOpacity: 1,
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
 
@@ -931,8 +952,8 @@ resizeOpacity: 1,
     buttons         : {
       close           : true,          // Boolean
       maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -943,7 +964,7 @@ resizeOpacity: 1,
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
 
@@ -955,8 +976,8 @@ resizeOpacity: 1,
     buttons         : {
       close           : true,          // Boolean
       maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -967,7 +988,7 @@ resizeOpacity: 1,
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
 
@@ -979,8 +1000,8 @@ resizeOpacity: 1,
     buttons         : {
       close           : true,          // Boolean
       maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -991,7 +1012,7 @@ resizeOpacity: 1,
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
 
@@ -1003,8 +1024,8 @@ resizeOpacity: 1,
     buttons         : {
       close           : true,          // Boolean
       maximize        : false,          // Boolean
-      collapse        : false,          // Boolean
-      minimize        : false,          // Boolean
+      collapse        : true,          // Boolean
+      minimize        : true,          // Boolean
   },
   buttonsTexts        : {
     close               : "退出",
@@ -1015,7 +1036,7 @@ resizeOpacity: 1,
   draggable           : true,
   nativeDrag          : true,
   dragOpacity         : 1,
-  resizable:false,
+  resizable:true,
   resizeOpacity: 1,
   });
   var com_list
@@ -1055,14 +1076,14 @@ resizeOpacity: 1,
   });
   $("#DKmodel").on("click", function(event){
     var dk=chatSocket.send(JSON.stringify({'msg':'remote_desktop'}))
-    
     $("#DK_content").PopupWindow("open");
   });
 }
 
-$("#pip_content").on("minimize.popupwindow", function(event){
+$("#pip_content").on("open.popupwindow", function(event){
   var models=document.getElementsByClassName('popupwindow_overlay')
-  models[0].style.width='0px'
+  models[0].style.width='-'
+  console.log(123)
 })
 
 $("#pip_content").on("collapse.popupwindow", function(event){
@@ -1584,22 +1605,24 @@ function c_list(){
     {id:6, name:"创建桌面应用程序",  col:"PyQt5创建GUI",cheese:ce('6')},
     {id:7, name:"创建桌面应用程序(交互)",  col:"PyQt5创建交互GUI",cheese:ce('7')},
     {id:8, name:"色块识别",  col:"进行色块识别",cheese:ce('18')},
-    {id:9, name:"调用百度AI",  col:"调用被百度AI进行图像识别",cheese:ce('8')},
-    {id:10, name:"调用百度AI_2",  col:"调用被百度AI进行语音识别",cheese:ce('9')},
-    {id:11, name:"调用百度AI_3",  col:"调用被百度AI进行语音合成",cheese:ce('10')},
-    {id:12, name:"MediaPipe-1", col:"使用MediaPipe进行人脸检测",cheese:ce('11')},
-    {id:13, name:"MediaPipe-2",  col:"使用MediaPipe进行面网",cheese:ce('12')},
-    {id:14, name:"MediaPipe-3",  col:"使用MediaPipe进行手部检测",cheese:ce('13')},
-    {id:15, name:"MediaPipe-3-1",  col:"使用MediaPipe进行手部检测,并连线（由顺德区龙江实验学校张楚彬老师贡献）",cheese:ce('17')},
-    {id:16, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
-    {id:17, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
-    {id:18, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
-    {id:19, name:"行空板-1",  col:"行空板打开摄像头",cheese:ce('19')},
-    {id:20, name:"行空板-2",  col:"行空板进行色块识别",cheese:ce('20')},
-    {id:21, name:"行空板-3",  col:"行空板进行目标检测",cheese:ce('21')},
-    {id:22, name:"行空板-4",  col:"行空板GET网络天气进行显示",cheese:ce('22')},
-    {id:23, name:"行空板-5",  col:"行空板PyQt交互案例",cheese:ce('23')},
-    {id:24, name:"行空板-6",  col:"行空板PyQt试试绘制加速度值，需要安装pyqtgraph",cheese:ce('24')},
+    {id:9, name:"追踪目标",  col:"使用OpenCV追踪目标",cheese:ce('25')},
+    {id:10, name:"调用百度AI",  col:"调用被百度AI进行图像识别",cheese:ce('8')},
+    {id:11, name:"调用百度AI_2",  col:"调用被百度AI进行语音识别",cheese:ce('9')},
+    {id:12, name:"调用百度AI_3",  col:"调用被百度AI进行语音合成",cheese:ce('10')},
+    {id:13, name:"MediaPipe-1", col:"使用MediaPipe进行人脸检测",cheese:ce('11')},
+    {id:14, name:"MediaPipe-2",  col:"使用MediaPipe进行面网",cheese:ce('12')},
+    {id:15, name:"MediaPipe-3",  col:"使用MediaPipe进行手部检测",cheese:ce('13')},
+    {id:16, name:"MediaPipe-3-1",  col:"使用MediaPipe进行手部检测,并连线（由顺德区龙江实验学校张楚彬老师贡献）",cheese:ce('17')},
+    {id:17, name:"MediaPipe-3-2",  col:"使用MediaPipe进行手势辨识",cheese:ce('26')},
+    {id:18, name:"MediaPipe-4",  col:"使用MediaPipe进行人体姿态检测",cheese:ce('14')},
+    {id:19, name:"目标识别",  col:"进行模型推理、目标识别",cheese:ce('15')},
+    {id:20, name:"图像分类",  col:"进行模型推理、图像分类",cheese:ce('16')},
+    {id:21, name:"行空板-1",  col:"行空板打开摄像头",cheese:ce('19')},
+    {id:22, name:"行空板-2",  col:"行空板进行色块识别",cheese:ce('20')},
+    {id:23, name:"行空板-3",  col:"行空板进行目标检测",cheese:ce('21')},
+    {id:24, name:"行空板-4",  col:"行空板GET网络天气进行显示",cheese:ce('22')},
+    {id:25, name:"行空板-5",  col:"行空板PyQt交互案例",cheese:ce('23')},
+    {id:26, name:"行空板-6",  col:"行空板PyQt试试绘制加速度值，需要安装pyqtgraph",cheese:ce('24')},
   ]);
 }
 var model_lists
