@@ -8,26 +8,18 @@ Blockly.Blocks.yolo_fast_init= {
         .setCheck(null)
         .setAlign(Blockly.ALIGN_RIGHT)
         .appendField("标签");
-    this.appendValueInput("ANCHOR")
+    this.appendValueInput("WH")
         .setCheck(null)
         .setAlign(Blockly.ALIGN_RIGHT)
-        .appendField("Anchor");
+        .appendField("模型输入高宽");
     this.appendValueInput("OBJ")
         .setCheck(null)
         .setAlign(Blockly.ALIGN_RIGHT)
-        .appendField("对象置信度");
-    this.appendValueInput("CONF")
-        .setCheck(null)
-        .setAlign(Blockly.ALIGN_RIGHT)
-        .appendField("种类置信度");
-    this.appendValueInput("NMS")
-        .setCheck(null)
-        .setAlign(Blockly.ALIGN_RIGHT)
-        .appendField("Nms-iou");
+        .appendField("置信度");
     this.setInputsInline(false);
     this.setOutput(true, null);
     this.setStyle('AI_blocks');
-    this.setTooltip("初始化Yolo-Fast网络");
+    this.setTooltip("初始化Yolo网络");
     this.setHelpUrl("");
     }
   };
@@ -150,4 +142,112 @@ Blockly.Blocks.yolo_fast_init= {
     }
   };
 
+  Blockly.Blocks.audio_classify= {
+    init: function() {
+    this.appendValueInput("MODEL")
+        .setCheck(null)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("初始化音频分类器 模型");
+    this.appendValueInput("MAX")
+        .setCheck(null)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("返回结果最大数量");
+    this.setInputsInline(false);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("初始化音频分类器");
+    this.setHelpUrl("");
+    }
+  };
+
+  Blockly.Blocks.audio_classify_run= {
+    init: function() {
+    this.appendValueInput("VAR")
+        .setCheck(null)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("运行音频分类器");
+    this.appendValueInput("WAV")
+        .setCheck(null)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("推理音频");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("运行音频分类器推理音频,结果放回一个列表对象");
+    this.setHelpUrl("");
+    }
+  };
+
+  Blockly.Blocks.SoundThread= {
+    init: function() {
+    this.appendValueInput("MODEL")
+        .setCheck(String)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("初始化实时音频分类器 模型");
+    this.appendValueInput("MAX")
+        .setCheck(Number)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("返回最大结果数量");
+    this.appendValueInput("SCORE")
+        .setCheck(Number)
+        .setAlign(Blockly.ALIGN_RIGHT)
+        .appendField("阈值(0~1)");
+    this.setInputsInline(false);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("初始化实时音频分类器");
+    this.setHelpUrl("");
+    }
+  };
+
+  Blockly.Blocks.SoundThread_get= {
+    init: function() {
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("获取实时音频分类器");
+    this.appendDummyInput()
+        .appendField("结果");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("获取实时音频分类器结果");
+    this.setHelpUrl("");
+    }
+  };
+
+
+  Blockly.Blocks.classifier_win_init= {
+    init: function() {
+    this.appendDummyInput()
+        .appendField("初始化图像分类");
+    this.appendValueInput("MODEL")
+        .setCheck(null)
+        .appendField("模型");
+    this.appendValueInput("CLASS")
+        .setCheck(null)
+        .appendField("种类");
+    this.setInputsInline(false);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("初始化图像分类网络");
+    this.setHelpUrl("");
+    }
+  };
+
+
+  Blockly.Blocks.class_process= {
+    init: function() {
+    this.appendValueInput("NAME")
+        .setCheck(null)
+        .appendField("运行网络");
+    this.appendValueInput("IMG")
+        .setCheck(null)
+        .appendField("推理图片");
+    this.setInputsInline(true);
+    this.setOutput(true, null);
+    this.setStyle('AI_blocks');
+    this.setTooltip("运行图像分类网络进行推理，返回识别结果");
+    this.setHelpUrl("");
+    }
+  };
   
\ No newline at end of file
